% Constructor of the finite element block class to be used with small
% displacement, small strain    deformation mechanics for continuum,
% isoparametric elements.
%
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing options.
% Options: those recognized by feblock
%
function self = feblock_defor_ss (varargin)
    class_name='feblock_defor_ss';
    if (nargin == 0)
        parent = feblock;
        self.matstates= [];
        self = class(self,class_name,parent);
        return;
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            self = arg;
            return;
        else
            parent = feblock(varargin{:});
            self.matstates = [];
            self = class(self,class_name,parent);
            integration_rule = get(self.feblock, 'integration_rule');
            npts_per_gcell = get(integration_rule, 'npts_per_gcell');
            gcells = get(self.feblock,'gcells');
            ngcells = length(gcells);
            self.matstates = cell(get(gcells(1),'nfens')*ngcells,npts_per_gcell);
            mat = get(self.feblock, 'mater');
            for i=1:ngcells
                for j=1:npts_per_gcell;
                    self.matstates{i,j} = newmatstate(mat);
                end
            end
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end

