% Draw a graphic representation.
%
% Input arguments
% self = self
% gv = graphic viewer
% context = struct
% with mandatory fields
%    geom=geometry field
% with optional fields
% facecolor = color of the faces, solid
% colorfield =field with vertex colors
% only one of the facecolor and colorfield may be supplied
%  shrink = shrink factor
%
function draw (self, gv, context)
    conn = get(self, 'conn'); % connectivity
    x = gather(context.x, conn, 'values', 'noreshape'); % coordinates of nodes
    u = gather(context.u, conn, 'values', 'noreshape'); % coordinates of nodes
    xu=x+u;
    if isfield(context,'shrink')
        % RAW
    end
    if (isfield(context,'colorfield'))
        colors =gather(context.colorfield, conn, 'values', 'noreshape'); % coordinates of nodes
        options=struct ('colors',colors);
    else
        facecolor = 'red';
        if (isfield(context,'facecolor'))
            facecolor = context.facecolor;
        end
        options=struct ('facecolor',facecolor);
    end
    draw_polygon (gv, xu, [1, 7, 3, 6, 2, 5], options);
    draw_polygon (gv, xu, [1, 5, 2, 9, 4, 8], options);
    draw_polygon (gv, xu, [2, 6, 3, 10, 4, 9], options);
    draw_polygon (gv, xu, [3, 7, 1, 8, 4, 10], options);
    return;
end
