% Mesh files
%
% Graphics utility:
%   drawmesh           - Draw a finite element mesh.
%
% Mesh creation functions:
%   at3block2d         - Mesh of a rectangle located in a given range
%   at3block2dc        - Mesh of a rectangle located in a given range
%   block              - Mesh of a block located in a given range, H8 cells
%   block1d            - Mesh of a line segment located in a given range, L2
%                        cells
%   block2d            - Mesh of a rectangle located in a given range
%   blockH20           - Mesh of a block located in a given range, H20 cells
%   ct3block2d         - Mesh of a rectangle located in a given range
%   extrudeq4          - Extrude a mesh of quadrilaterals into a mesh of hexahedra.
%   extrudet3          - Extrude a mesh of triangles into a mesh of Tetrahedra.
%   mesh_hexahedron    - Mesh of a general hexahedron given by the location of the
%                        corners
%   mesh_quadrilateral - Mesh of a general quadrilateral given by the location of the
%                        corners
%   q4sphere           - Create the surface mesh of 1/8 of a sphere
%   q4circle           - Create the surface mesh of 1/4 of a  circular disc
%   t3annulus          - Mesh of an annulus segment in the first quadrant, centered at the origin,
%   t3block2d          - Mesh of a rectangle located in a given range
%   t3block2dc         - Mesh of a rectangle located in a given range
%   t3block2du         - Mesh of a rectangle located in a given range
%   t3block2dn         - Mesh of a rectangle located in a given range
%   t4block            - Tetrahedral (t4) Mesh of a block located in a given range
%   t4blockT10         - Tetrahedral (t4) Mesh of a block located in a given range
%   t4blockdel         - Tetrahedral (t4) Delaunay Mesh of a block located in a given range
%   t4cylinderdel      - Tetrahedral (t4) Delaunay Mesh of a cylinder of Length and Radius.
%   targe2_mesher      - Automatic triangulation of the domain. 
%   targe2_mesher_ vl  - Automatic triangulation of the domain, input is a
%                        polygon.
% 
% Conversion functions (from linear to quadratic):
%   H8_to_H20          - Convert a mesh of hexahedron H8 to hexahedron H20.
%   Q4_to_Q8           - Convert a mesh of quadrilateral Q4 to quadrilateral Q8.
%   T3_to_T6           - Convert a mesh of triangle T3 (three-node) to triangle T6.
%   T4_to_T10          - Convert a mesh of Tetrahedron T4 (four-node) to Tetrahedron T10.
%   Q4_to_aT3          - Convert a mesh of quadrilateral Q4's to 2 triangles T3 each.
%   Q4_to_T3           - Convert a mesh of quadrilateral Q4's to 2 triangles T3 each.
%
% Mesh manipulation functions:
%   fenode_select      - Select nodes using some criterion, for instance and node is selected
%   gcell_select       - Select geometric cells using some criterion, for instance a gcell is selected
%   merge_meshes       - Merge two meshes together by gluing together nodes within tolerance.
%   mesh_bdry          - Extract the boundary gcells of manifold dimension (n-1) from the
%   onto_sphere        - Auxiliary function to move nodes onto the surface
%                        of a sphere by radial protection
%   refineq4           - make a search structure for edges
%   transform_2_helix  - Apply geometry transformation to the nodes to produce a helix. It is
%   transform_apply    - Apply geometry transformation to the nodes to produce a helix. It is
%   block2d_random_shift - The locations of the nodes are shifted randomly, but so that nodes on the
%                        boundary remain on the boundary.
% Miscellaneous meshes:
%   annulus            - Mesh of an annulus segment in the first quadrant, centered at the origin,
%   L2x2               - 2 x 2 quadrilateral element mesh of one quarter of a square domain with a square hole.
%   arc2               - finer mesh of an arc
%   barrelq            - The Scordelis-Lo barrel vault: radius r=25 ft, subtended angle of 80
%   bridge             - concrete bridge model
%   holyplate2         - mesh of a quarter-plate with a hole: 2x2 division
%   mpart              - mesh of a simple mechanical part
%   portal             - mesh of a single hexahedron
